pub struct BrowserChunkingContext { /* private fields */ }Expand description
A chunking context for development mode.
It uses readable filenames and module ids to improve development. It also uses a chunking heuristic that is incremental and cacheable. It splits “node_modules” separately as these are less likely to change during development
Implementations
Sourceimpl BrowserChunkingContext
impl BrowserChunkingContext
pub fn builder( root_path: FileSystemPath, output_root: FileSystemPath, output_root_to_root_path: RcStr, client_root: FileSystemPath, chunk_root_path: FileSystemPath, asset_root_path: FileSystemPath, environment: ResolvedVc<Environment>, runtime_type: RuntimeType, ) -> BrowserChunkingContextBuilder
Sourceimpl BrowserChunkingContext
impl BrowserChunkingContext
pub fn current_chunk_method(self: Vc<Self>) -> Vc<CurrentChunkMethod>
pub fn hash_salt(self: Vc<Self>) -> Vc<RcStr>
Sourcepub fn runtime_type(self: Vc<Self>) -> Vc<RuntimeType>
pub fn runtime_type(self: Vc<Self>) -> Vc<RuntimeType>
Returns the kind of runtime to include in output chunks.
This is defined directly on BrowserChunkingContext so it is zero-cost
when RuntimeType has a single variant.
Sourcepub fn worker_asset_prefix(self: Vc<Self>) -> Vc<Option<RcStr>>
pub fn worker_asset_prefix(self: Vc<Self>) -> Vc<Option<RcStr>>
Returns the worker base-path override. When Some, takes precedence
over chunk_base_path for the entrypoint URL and the module chunks
loaded inside the worker.
Sourcepub fn asset_suffix(self: Vc<Self>) -> Vc<AssetSuffix>
pub fn asset_suffix(self: Vc<Self>) -> Vc<AssetSuffix>
Returns the asset suffix path.
Sourcepub fn source_maps_type(self: Vc<Self>) -> Vc<SourceMapsType>
pub fn source_maps_type(self: Vc<Self>) -> Vc<SourceMapsType>
Returns the source map type.
Sourcepub fn minify_type(self: Vc<Self>) -> Vc<MinifyType>
pub fn minify_type(self: Vc<Self>) -> Vc<MinifyType>
Returns the minify type.
Sourcepub fn chunk_loading_global(self: Vc<Self>) -> Vc<RcStr>
pub fn chunk_loading_global(self: Vc<Self>) -> Vc<RcStr>
Returns the chunk loading global variable name. Defaults to “TURBOPACK” if not set.
pub fn cross_origin(self: Vc<Self>) -> Vc<CrossOrigin>